Struct exc_core::exchange::tickers::MakeTickersOptions
source · pub struct MakeTickersOptions { /* private fields */ }Expand description
Options for making a service to subscribe tickers.
Implementations
sourceimpl MakeTickersOptions
impl MakeTickersOptions
sourcepub fn prefer_trade_bid_ask(self, flag: bool) -> MakeTickersOptions
pub fn prefer_trade_bid_ask(self, flag: bool) -> MakeTickersOptions
Set whether to prefer use ticker from trade bid/ask. Default is false.
sourcepub fn first_trade(self, mode: FirstTrade) -> MakeTickersOptions
pub fn first_trade(self, mode: FirstTrade) -> MakeTickersOptions
Set how to get the first trade. Default is FirstTrade::Wait.
Only works when MakeTickersOptions::prefer_trade_bid_ask is true.
sourcepub fn is_prefer_trade_bid_ask(&self) -> bool
pub fn is_prefer_trade_bid_ask(&self) -> bool
Get whether to prefer use ticker from trade bid/ask.
sourcepub fn get_first_trade(&self) -> FirstTrade
pub fn get_first_trade(&self) -> FirstTrade
Get how to get the first trade.
sourcepub fn accept_bid_ask_ts(self, flag: bool) -> MakeTickersOptions
pub fn accept_bid_ask_ts(self, flag: bool) -> MakeTickersOptions
Accept bid/ask ts. Default is false. Only works when
MakeTickersOptions::prefer_trade_bid_ask is true.
sourcepub fn is_accept_bid_ask_ts(&self) -> bool
pub fn is_accept_bid_ask_ts(&self) -> bool
Get whether to accept bid/ask ts.