Struct exc_core::Instrument
source · pub struct Instrument { /* private fields */ }Expand description
Instrument.
Implementations
sourceimpl Instrument
impl Instrument
sourcepub fn try_new(
symbol: &str,
base: &Asset,
quote: &Asset
) -> Result<Instrument, ParseSymbolError>
pub fn try_new( symbol: &str, base: &Asset, quote: &Asset ) -> Result<Instrument, ParseSymbolError>
Create a new instrument.
Return ParseSymbolError if the format of the symbol is not valid.
sourcepub fn spot(base: &Asset, quote: &Asset) -> Instrument
pub fn spot(base: &Asset, quote: &Asset) -> Instrument
Create a new spot.
sourcepub fn derivative(
prefix: &str,
symbol: &str,
base: &Asset,
quote: &Asset
) -> Result<Instrument, ParseSymbolError>
pub fn derivative( prefix: &str, symbol: &str, base: &Asset, quote: &Asset ) -> Result<Instrument, ParseSymbolError>
Create a new derivative.
Return ParseSymbolError if the prefix is not valid.
Warning
User must make sure that inst1.symbol == inst2.symbol
only if inst1.base == inst2.base && inst1.quote == inst2.quote.
sourcepub fn to_reversed_spot(&self) -> Option<Instrument>
pub fn to_reversed_spot(&self) -> Option<Instrument>
Convert to the revsered spot.
Return None if it is not a spot.
sourcepub fn try_with_symbol(
symbol: Symbol,
base: &Asset,
quote: &Asset
) -> Result<Instrument, ParseSymbolError>
pub fn try_with_symbol( symbol: Symbol, base: &Asset, quote: &Asset ) -> Result<Instrument, ParseSymbolError>
Create a new instrument with the given symbol.
Return ParseSymbolError if the symbol does not match the given base or quote.
Warning
User must make sure that inst1.symbol == inst2.symbol
only if inst1.base == inst2.base && inst1.quote == inst2.quote.
sourcepub fn prefer_reversed(self, reversed: bool) -> Instrument
pub fn prefer_reversed(self, reversed: bool) -> Instrument
Whether to mark this instrument as a reversed-prefering.
Default to false.
sourcepub fn is_prefer_reversed(&self) -> bool
pub fn is_prefer_reversed(&self) -> bool
Is this instrument reversed-prefering.
Default to false.
sourcepub fn is_derivative(&self) -> bool
pub fn is_derivative(&self) -> bool
Is derivative.
sourcepub fn position<T, P>(&self, position: P) -> Position<T>where
T: PositionNum,
P: IntoNaivePosition<T>,
pub fn position<T, P>(&self, position: P) -> Position<T>where
T: PositionNum,
P: IntoNaivePosition<T>,
Create a Position with the given position of this instrument.